@@ -54,7 +54,7 @@ t.write()
 import os, re, sys
 import tempfile
 
-__version__ = '0.9.5'
+__version__ = '0.9.6'
 
 CRONCMD = "/usr/bin/crontab"
 ITEMREX = re.compile('^\s*([^@#\s]+)\s+([^@#\s]+)\s+([^@#\s]+)' +
@@ -151,7 +151,7 @@ class CronTab(object):
                 continue
             crons.append(unicode(cron))
         result = '\n'.join(crons)
-        if result[-1] not in [ '\n', '\r' ]:
+        if result and result[-1] not in [ '\n', '\r' ]:
             result += '\n'
         return result
 
